@@ -1309,7 +1309,15 @@ class SE3(SO3):
         """
         return cls([base.transl(0, 0, _z) for _z in base.getvector(z)], check=False)
 
-
+    @classmethod
+    def SO3(cls, R, check=True):
+        if isinstance(R, SO3):
+            R = R.A
+        elif base.isrot(R, check=check):
+            pass
+        else:
+            raise ValueError('expecting SO3 or rotation matrix')
+        return cls(base.r2t(R))
 
 if __name__ == '__main__':   # pragma: no cover
 
@@ -1321,4 +1329,4 @@ if __name__ == '__main__':   # pragma: no cover
     a = SE3.Rx(np.pi/2)
     print(a)
 
-    exec(open(pathlib.Path(__file__).parent.absolute() / "test" / "test_pose3d.py").read())  # pylint: disable=exec-used
+    exec(open(pathlib.Path(__file__).parent.parent.absolute() / "tests" / "test_pose3d.py").read())  # pylint: disable=exec-used
